==> sc2_datasets-1.0.0.tar.gz: sc2_datasets-1.0.0/src/sc2_datasets/available_replaypacks.py <==
"""
    Module docstring
"""

EXAMPLE_SYNTHETIC_REPLAYPACKS = [
    (
        "2022_TestReplaypack",
        "https://github.com/Kaszanas/SC2EGSet_Dataset/raw/working_on_docs/tests/test_files/2022_TestReplaypack.zip",  # noqa
    )
]

EXAMPLE_REAL_REPLAYPACKS = [
    (
        "2016_IEM_10_Taipei",
        "https://zenodo.org/record/6903505/files/2016_IEM_10_Taipei.zip?download=1",
    ),
    (
        "2016_IEM_11_Shanghai",
        "https://zenodo.org/record/6903505/files/2016_IEM_11_Shanghai.zip?download=1",
    ),
]

SC2EGSET_DATASET_REPLAYPACKS = [
    (
        "2016_IEM_10_Taipei",
        "https://zenodo.org/record/6903505/files/2016_IEM_10_Taipei.zip?download=1",
    ),
    (
        "2016_IEM_11_Shanghai",
        "https://zenodo.org/record/6903505/files/2016_IEM_11_Shanghai.zip?download=1",
    ),
    (
        "2016_WCS_Winter",
        "https://zenodo.org/record/6903505/files/2016_WCS_Winter.zip?download=1",
    ),
    (
        "2017_HomeStory_Cup_XV",
        "https://zenodo.org/record/6903505/files/2017_HomeStory_Cup_XV.zip?download=1",
    ),
    (
        "2017_HomeStory_Cup_XVI",
        "https://zenodo.org/record/6903505/files/2017_HomeStory_Cup_XVI.zip?download=1",
    ),
    (
        "2017_IEM_Shanghai",
        "https://zenodo.org/record/6903505/files/2017_IEM_Shanghai.zip?download=1",
    ),
    (
        "2017_IEM_XI_World_Championship_Katowice",
        "https://zenodo.org/record/6903505/files/2017_IEM_XI_World_Championship_Katowice.zip?download=1",  # noqa
    ),
    (
        "2017_WCS_Austin",
        "https://zenodo.org/record/6903505/files/2017_WCS_Austin.zip?download=1",
    ),
    (
        "2017_WCS_Global_Finals",
        "https://zenodo.org/record/6903505/files/2017_WCS_Global_Finals.zip?download=1",
    ),
    (
        "2017_WCS_Jonkoping",
        "https://zenodo.org/record/6903505/files/2017_WCS_Jonkoping.zip?download=1",
    ),
    (
        "2017_WCS_Montreal",
        "https://zenodo.org/record/6903505/files/2017_WCS_Montreal.zip?download=1",
    ),
    (
        "2017_WESG_Barcelona",
        "https://zenodo.org/record/6903505/files/2017_WESG_Barcelona.zip?download=1",
    ),
    (
        "2017_WESG_Haikou",
        "https://zenodo.org/record/6903505/files/2017_WESG_Haikou.zip?download=1",
    ),
    (
        "2018_Cheeseadelphia_8",
        "https://zenodo.org/record/6903505/files/2018_Cheeseadelphia_8.zip?download=1",
    ),
    (
        "2018_HomeStory_Cup_XVII",
        "https://zenodo.org/record/6903505/files/2018_HomeStory_Cup_XVII.zip?download=1",
    ),
    (
        "2018_HomeStory_Cup_XVIII",
        "https://zenodo.org/record/6903505/files/2018_HomeStory_Cup_XVII.zip?download=1",
    ),
    (
        "2018_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2018_IEM_Katowice.zip?download=1",
    ),
    (
        "2018_IEM_PyeongChang",
        "https://zenodo.org/record/6903505/files/2018_IEM_PyeongChang.zip?download=1",
    ),
    (
        "2018_WCS_Austin",
        "https://zenodo.org/record/6903505/files/2018_WCS_Austin.zip?download=1",
    ),
    (
        "2018_WCS_Global_Finals",
        "https://zenodo.org/record/6903505/files/2018_WCS_Global_Finals.zip?download=1",
    ),
    (
        "2018_WCS_Leipzig",
        "https://zenodo.org/record/6903505/files/2018_WCS_Leipzig.zip?download=1",
    ),
    (
        "2018_WCS_Montreal",
        "https://zenodo.org/record/6903505/files/2018_WCS_Montreal.zip?download=1",
    ),
    (
        "2018_WCS_Valencia",
        "https://zenodo.org/record/6903505/files/2018_WCS_Valencia.zip?download=1",
    ),
    (
        "2018_WESG_Grand_Finals",
        "https://zenodo.org/record/6903505/files/2018_WESG_Grand_Finals.zip?download=1",
    ),
    (
        "2019_Assembly_Summer",
        "https://zenodo.org/record/6903505/files/2019_Assembly_Summer.zip?download=1",
    ),
    (
        "2019_HomeStory_Cup_XIX",
        "https://zenodo.org/record/6903505/files/2019_HomeStory_Cup_XIX.zip?download=1",
    ),
    (
        "2019_HomeStory_Cup_XX",
        "https://zenodo.org/record/6903505/files/2019_HomeStory_Cup_XX.zip?download=1",
    ),
    (
        "2019_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2019_IEM_Katowice.zip?download=1",
    ),
    (
        "2019_WCS_Fall",
        "https://zenodo.org/record/6903505/files/2019_WCS_Fall.zip?download=1",
    ),
    (
        "2019_WCS_Grand_Finals",
        "https://zenodo.org/record/6903505/files/2019_WCS_Grand_Finals.zip?download=1",
    ),
    (
        "2019_WCS_Spring",
        "https://zenodo.org/record/6903505/files/2019_WCS_Spring.zip?download=1",
    ),
    (
        "2019_WCS_Summer",
        "https://zenodo.org/record/6903505/files/2019_WCS_Summer.zip?download=1",
    ),
    (
        "2019_WCS_Winter",
        "https://zenodo.org/record/6903505/files/2019_WCS_Winter.zip?download=1",
    ),
    (
        "2020_05_Dreamhack_Last_Chance",
        "https://zenodo.org/record/6903505/files/2020_05_Dreamhack_Last_Chance.zip?download=1",
    ),
    (
        "2020_ASUS_ROG_Online",
        "https://zenodo.org/record/6903505/files/2020_ASUS_ROG_Online.zip?download=1",
    ),
    (
        "2020_Dreamhack_SC2_Masters_Fall",
        "https://zenodo.org/record/6903505/files/2020_Dreamhack_SC2_Masters_Fall.zip?download=1",
    ),
    (
        "2020_Dreamhack_SC2_Masters_Summer",
        "https://zenodo.org/record/6903505/files/2020_Dreamhack_SC2_Masters_Summer.zip?download=1",
    ),
    (
        "2020_Dreamhack_SC2_Masters_Winter",
        "https://zenodo.org/record/6903505/files/2020_Dreamhack_SC2_Masters_Summer.zip?download=1",
    ),
    (
        "2020_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2020_IEM_Katowice.zip?download=1",
    ),
    (
        "2020_StayAtHome_Story_Cup_1",
        "https://zenodo.org/record/6903505/files/2020_StayAtHome_Story_Cup_1.zip?download=1",
    ),
    (
        "2020_StayAtHome_Story_Cup_2",
        "https://zenodo.org/record/6903505/files/2020_StayAtHome_Story_Cup_2.zip?download=1",
    ),
    (
        "2020_TSL5",
        "https://zenodo.org/record/6903505/files/2020_TSL5.zip?download=1",
    ),
    (
        "2020_TSL6",
        "https://zenodo.org/record/6903505/files/2020_TSL6.zip?download=1",
    ),
    (
        "2021_ASUS_ROG_Fall",
        "https://zenodo.org/record/6903505/files/2021_ASUS_ROG_Fall.zip?download=1",
    ),
    (
        "2021_Cheeseadelphia_Winter_Championship",
        "https://zenodo.org/record/6903505/files/2021_Cheeseadelphia_Winter_Championship.zip?download=1",  # noqa
    ),
    (
        "2021_Dreamhack_SC2_Masters_Fall",
        "https://zenodo.org/record/6903505/files/2021_Dreamhack_SC2_Masters_Fall.zip?download=1",
    ),
    (
        "2021_Dreamhack_SC2_Masters_Summer",
        "https://zenodo.org/record/6903505/files/2021_Dreamhack_SC2_Masters_Summer.zip?download=1",
    ),
    (
        "2021_Dreamhack_SC2_Masters_Winter",
        "https://zenodo.org/record/6903505/files/2021_Dreamhack_SC2_Masters_Winter.zip?download=1",
    ),
    (
        "2021_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2021_IEM_Katowice.zip?download=1",
    ),
    (
        "2021_StayAtHome_Story_Cup_3",
        "https://zenodo.org/record/6903505/files/2021_StayAtHome_Story_Cup_3.zip?download=1",
    ),
    (
        "2021_StayAtHome_Story_Cup_4",
        "https://zenodo.org/record/6903505/files/2021_StayAtHome_Story_Cup_4.zip?download=1",
    ),
    (
        "2021_TSL7",
        "https://zenodo.org/record/6903505/files/2021_TSL7.zip?download=1",
    ),
    (
        "2021_TSL8",
        "https://zenodo.org/record/6903505/files/2021_TSL8.zip?download=1",
    ),
    (
        "2022_Dreamhack_SC2_Masters_Last_Chance2021",
        "https://zenodo.org/record/6903505/files/2022_Dreamhack_SC2_Masters_Last_Chance2021.zip?download=1",  # noqa
    ),
    (
        "2022_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2022_IEM_Katowice.zip?download=1",
    ),
]

==> sc2_datasets-1.0.2.tar.gz: sc2_datasets-1.0.2/src/sc2_datasets/available_replaypacks.py <==
"""
    Module docstring
"""

EXAMPLE_SYNTHETIC_REPLAYPACKS = [
    (
        "2022_TestReplaypack",
        "https://github.com/Kaszanas/SC2EGSet_Dataset/raw/main/tests/test_files/2022_TestReplaypack.zip",  # noqa
    )
]

EXAMPLE_REAL_REPLAYPACKS = [
    (
        "2016_IEM_10_Taipei",
        "https://zenodo.org/record/6903505/files/2016_IEM_10_Taipei.zip?download=1",
    ),
    (
        "2016_IEM_11_Shanghai",
        "https://zenodo.org/record/6903505/files/2016_IEM_11_Shanghai.zip?download=1",
    ),
]

SC2EGSET_DATASET_REPLAYPACKS = [
    (
        "2016_IEM_10_Taipei",
        "https://zenodo.org/record/6903505/files/2016_IEM_10_Taipei.zip?download=1",
    ),
    (
        "2016_IEM_11_Shanghai",
        "https://zenodo.org/record/6903505/files/2016_IEM_11_Shanghai.zip?download=1",
    ),
    (
        "2016_WCS_Winter",
        "https://zenodo.org/record/6903505/files/2016_WCS_Winter.zip?download=1",
    ),
    (
        "2017_HomeStory_Cup_XV",
        "https://zenodo.org/record/6903505/files/2017_HomeStory_Cup_XV.zip?download=1",
    ),
    (
        "2017_HomeStory_Cup_XVI",
        "https://zenodo.org/record/6903505/files/2017_HomeStory_Cup_XVI.zip?download=1",
    ),
    (
        "2017_IEM_Shanghai",
        "https://zenodo.org/record/6903505/files/2017_IEM_Shanghai.zip?download=1",
    ),
    (
        "2017_IEM_XI_World_Championship_Katowice",
        "https://zenodo.org/record/6903505/files/2017_IEM_XI_World_Championship_Katowice.zip?download=1",  # noqa
    ),
    (
        "2017_WCS_Austin",
        "https://zenodo.org/record/6903505/files/2017_WCS_Austin.zip?download=1",
    ),
    (
        "2017_WCS_Global_Finals",
        "https://zenodo.org/record/6903505/files/2017_WCS_Global_Finals.zip?download=1",
    ),
    (
        "2017_WCS_Jonkoping",
        "https://zenodo.org/record/6903505/files/2017_WCS_Jonkoping.zip?download=1",
    ),
    (
        "2017_WCS_Montreal",
        "https://zenodo.org/record/6903505/files/2017_WCS_Montreal.zip?download=1",
    ),
    (
        "2017_WESG_Barcelona",
        "https://zenodo.org/record/6903505/files/2017_WESG_Barcelona.zip?download=1",
    ),
    (
        "2017_WESG_Haikou",
        "https://zenodo.org/record/6903505/files/2017_WESG_Haikou.zip?download=1",
    ),
    (
        "2018_Cheeseadelphia_8",
        "https://zenodo.org/record/6903505/files/2018_Cheeseadelphia_8.zip?download=1",
    ),
    (
        "2018_HomeStory_Cup_XVII",
        "https://zenodo.org/record/6903505/files/2018_HomeStory_Cup_XVII.zip?download=1",
    ),
    (
        "2018_HomeStory_Cup_XVIII",
        "https://zenodo.org/record/6903505/files/2018_HomeStory_Cup_XVII.zip?download=1",
    ),
    (
        "2018_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2018_IEM_Katowice.zip?download=1",
    ),
    (
        "2018_IEM_PyeongChang",
        "https://zenodo.org/record/6903505/files/2018_IEM_PyeongChang.zip?download=1",
    ),
    (
        "2018_WCS_Austin",
        "https://zenodo.org/record/6903505/files/2018_WCS_Austin.zip?download=1",
    ),
    (
        "2018_WCS_Global_Finals",
        "https://zenodo.org/record/6903505/files/2018_WCS_Global_Finals.zip?download=1",
    ),
    (
        "2018_WCS_Leipzig",
        "https://zenodo.org/record/6903505/files/2018_WCS_Leipzig.zip?download=1",
    ),
    (
        "2018_WCS_Montreal",
        "https://zenodo.org/record/6903505/files/2018_WCS_Montreal.zip?download=1",
    ),
    (
        "2018_WCS_Valencia",
        "https://zenodo.org/record/6903505/files/2018_WCS_Valencia.zip?download=1",
    ),
    (
        "2018_WESG_Grand_Finals",
        "https://zenodo.org/record/6903505/files/2018_WESG_Grand_Finals.zip?download=1",
    ),
    (
        "2019_Assembly_Summer",
        "https://zenodo.org/record/6903505/files/2019_Assembly_Summer.zip?download=1",
    ),
    (
        "2019_HomeStory_Cup_XIX",
        "https://zenodo.org/record/6903505/files/2019_HomeStory_Cup_XIX.zip?download=1",
    ),
    (
        "2019_HomeStory_Cup_XX",
        "https://zenodo.org/record/6903505/files/2019_HomeStory_Cup_XX.zip?download=1",
    ),
    (
        "2019_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2019_IEM_Katowice.zip?download=1",
    ),
    (
        "2019_WCS_Fall",
        "https://zenodo.org/record/6903505/files/2019_WCS_Fall.zip?download=1",
    ),
    (
        "2019_WCS_Grand_Finals",
        "https://zenodo.org/record/6903505/files/2019_WCS_Grand_Finals.zip?download=1",
    ),
    (
        "2019_WCS_Spring",
        "https://zenodo.org/record/6903505/files/2019_WCS_Spring.zip?download=1",
    ),
    (
        "2019_WCS_Summer",
        "https://zenodo.org/record/6903505/files/2019_WCS_Summer.zip?download=1",
    ),
    (
        "2019_WCS_Winter",
        "https://zenodo.org/record/6903505/files/2019_WCS_Winter.zip?download=1",
    ),
    (
        "2020_05_Dreamhack_Last_Chance",
        "https://zenodo.org/record/6903505/files/2020_05_Dreamhack_Last_Chance.zip?download=1",
    ),
    (
        "2020_ASUS_ROG_Online",
        "https://zenodo.org/record/6903505/files/2020_ASUS_ROG_Online.zip?download=1",
    ),
    (
        "2020_Dreamhack_SC2_Masters_Fall",
        "https://zenodo.org/record/6903505/files/2020_Dreamhack_SC2_Masters_Fall.zip?download=1",
    ),
    (
        "2020_Dreamhack_SC2_Masters_Summer",
        "https://zenodo.org/record/6903505/files/2020_Dreamhack_SC2_Masters_Summer.zip?download=1",
    ),
    (
        "2020_Dreamhack_SC2_Masters_Winter",
        "https://zenodo.org/record/6903505/files/2020_Dreamhack_SC2_Masters_Summer.zip?download=1",
    ),
    (
        "2020_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2020_IEM_Katowice.zip?download=1",
    ),
    (
        "2020_StayAtHome_Story_Cup_1",
        "https://zenodo.org/record/6903505/files/2020_StayAtHome_Story_Cup_1.zip?download=1",
    ),
    (
        "2020_StayAtHome_Story_Cup_2",
        "https://zenodo.org/record/6903505/files/2020_StayAtHome_Story_Cup_2.zip?download=1",
    ),
    (
        "2020_TSL5",
        "https://zenodo.org/record/6903505/files/2020_TSL5.zip?download=1",
    ),
    (
        "2020_TSL6",
        "https://zenodo.org/record/6903505/files/2020_TSL6.zip?download=1",
    ),
    (
        "2021_ASUS_ROG_Fall",
        "https://zenodo.org/record/6903505/files/2021_ASUS_ROG_Fall.zip?download=1",
    ),
    (
        "2021_Cheeseadelphia_Winter_Championship",
        "https://zenodo.org/record/6903505/files/2021_Cheeseadelphia_Winter_Championship.zip?download=1",  # noqa
    ),
    (
        "2021_Dreamhack_SC2_Masters_Fall",
        "https://zenodo.org/record/6903505/files/2021_Dreamhack_SC2_Masters_Fall.zip?download=1",
    ),
    (
        "2021_Dreamhack_SC2_Masters_Summer",
        "https://zenodo.org/record/6903505/files/2021_Dreamhack_SC2_Masters_Summer.zip?download=1",
    ),
    (
        "2021_Dreamhack_SC2_Masters_Winter",
        "https://zenodo.org/record/6903505/files/2021_Dreamhack_SC2_Masters_Winter.zip?download=1",
    ),
    (
        "2021_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2021_IEM_Katowice.zip?download=1",
    ),
    (
        "2021_StayAtHome_Story_Cup_3",
        "https://zenodo.org/record/6903505/files/2021_StayAtHome_Story_Cup_3.zip?download=1",
    ),
    (
        "2021_StayAtHome_Story_Cup_4",
        "https://zenodo.org/record/6903505/files/2021_StayAtHome_Story_Cup_4.zip?download=1",
    ),
    (
        "2021_TSL7",
        "https://zenodo.org/record/6903505/files/2021_TSL7.zip?download=1",
    ),
    (
        "2021_TSL8",
        "https://zenodo.org/record/6903505/files/2021_TSL8.zip?download=1",
    ),
    (
        "2022_Dreamhack_SC2_Masters_Last_Chance2021",
        "https://zenodo.org/record/6903505/files/2022_Dreamhack_SC2_Masters_Last_Chance2021.zip?download=1",  # noqa
    ),
    (
        "2022_IEM_Katowice",
        "https://zenodo.org/record/6903505/files/2022_IEM_Katowice.zip?download=1",
    ),
]
